@@ -21,8 +21,13 @@
 #include "xsltconfig.h"
 #include <libxml/xmlversion.h>
 #endif
-#ifndef LIBXSLT_PUBLIC
-#define LIBXSLT_PUBLIC
+
+#if !defined LIBXSLT_PUBLIC
+#if defined _MSC_VER && !defined IN_LIBXSLT && !defined LIBXSLT_STATIC
+#define LIBXSLT_PUBLIC __declspec(dllimport)
+#else
+#define LIBXSLT_PUBLIC 
+#endif
 #endif
 
 #endif /* ! __XSLT_LIBXSLT_H__ */
