@@ -10,7 +10,7 @@
 #ifndef __XML_XSLTWIN32CONFIG_H__
 #define __XML_XSLTWIN32CONFIG_H__
 
-#include <win32config.h>
+#include "win32config.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -21,21 +21,21 @@ extern "C" {
  *
  * the version string like "1.2.3"
  */
-#define LIBXSLT_DOTTED_VERSION "1.0.9"
+#define LIBXSLT_DOTTED_VERSION "1.0.10"
 
 /**
  * LIBXSLT_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXSLT_VERSION 10009
+#define LIBXSLT_VERSION 10010
 
 /**
  * LIBXSLT_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXSLT_VERSION_STRING "10009"
+#define LIBXSLT_VERSION_STRING "10010"
 
 /**
  * WITH_XSLT_DEBUG:
